@@ -103,6 +103,10 @@ class CodecHelper:
                 value, elem_oid, protocol_format).encode('utf-8')
 
     def encode_array_text(self, value, elem_oid, protocol_format):
+        if not isinstance(value, list):
+            raise TypeError(
+                f'Expected a list for a postgres array; Got: {value!r}')
+
         if value:
             self.check_array_dims(value)
 
@@ -114,8 +118,15 @@ class CodecHelper:
                 ret += self.encode_array_text(
                     elem, elem_oid, protocol_format)
             else:
-                ret += self.encode_value(
+                encoded_elem = self.encode_value(
                     elem, elem_oid, protocol_format).decode('utf-8')
+                if '\\' in encoded_elem:
+                    encoded_elem = encoded_elem.replace('\\', '\\\\')
+                if '"' in encoded_elem:
+                    encoded_elem = encoded_elem.replace('"', '\\"')
+                if any(c in '{},"' for c in encoded_elem):
+                    encoded_elem = f'"{encoded_elem}"'
+                ret += encoded_elem
         ret += '}'
         return ret
 
@@ -187,11 +198,23 @@ class CodecHelper:
                 'Each array level should either be all other arrays, '
                 'or all non-arrays.')
 
-    def decode_row(self, columns, row_desc):
-        row = []
-        for col, col_desc in zip(columns, row_desc):
-            row.append(self.decode_col(col, col_desc))
-        return tuple(row)
+    def decode_row(self, columns, row_desc, tuple_class=None):
+        def make_tuple(*items):
+            # we need this function, because we cannot pass the tuple
+            # built-in a single argument and expect it to create a
+            # tuple of size one. When passed a single argument, it
+            # assumes it's an iterable and tries to convert it to a
+            # tuple.
+            return tuple(items)
+
+        tuple_class = tuple_class or make_tuple
+        print('x', tuple_class)
+        return tuple_class(
+            *(
+                self.decode_col(col, col_desc)
+                for col, col_desc in zip(columns, row_desc)
+            )
+        )
 
     def decode_col(self, col, col_desc):
         if col is None:
